@@ -265,7 +265,7 @@ contains
 
    function init_gt4_named_realary(name,rank,dims,length,ary,longname,units) &
 	& result(result)
-      use dc_error, only: USR_ECHAR, StoreError
+      use dc_error, only: USR_ERRNO, StoreError
       implicit none
       type(GT4_NAMED_REALARY)            :: result
       !
@@ -280,7 +280,7 @@ contains
       character(len = *), parameter:: subname = 'init_gt4_named_realary'
       !
       call BeginSub(subname)
-      if(rank>3 .or. rank<0) call StoreError(USR_ECHAR, subname, &
+      if(rank>3 .or. rank<0) call StoreError(USR_ERRNO, subname, &
 	      &   cause_c='rank must be <= 3 and >=1')
       result%rank = rank
       result%name = name
@@ -622,7 +622,7 @@ contains
    subroutine HistoryAutoSetRunInfo( &
 	& title, source, institution, proc, &
         & conventions, gt_version  )
-      use dc_error, only: USR_EINT, StoreError
+      use dc_error, only: USR_ERRNO, StoreError
       implicit none
       character(len=*), intent(in), optional     :: title, source, institution
       character(len=*), intent(in), optional     :: proc
@@ -646,7 +646,7 @@ contains
         & dims, axlongnames, axunits, axxtypes, &
 	& coord1, coord2, coord3, ancilcrdvars, &
         & subdomfst )
-      use dc_error, only: USR_EINT, StoreError
+      use dc_error, only: USR_ERRNO, StoreError
       implicit none
       character(len=*), intent(in)     :: grid_label
       integer, intent(in)              :: aryshape(:) ! size <= 3 (--> sprank)
@@ -708,7 +708,7 @@ contains
 	& attrs, &
         & grid_label, &
 	& title, source, institution, conventions, gt_version, proc )
-      use dc_error, only: USR_ECHAR, USR_EINT, StoreError
+      use dc_error, only: USR_ERRNO, USR_ERRNO, StoreError
       implicit none
       character(len=*), intent(in)     :: name
       character(len=*), intent(in)     :: longname
@@ -732,7 +732,7 @@ contains
       call BeginSub(subname)
       ith = 1
       if (.not.histpl_find(HISTGRIDPOOL, grid_label, ith, hist)) then
-	 call StoreError(USR_ECHAR, subname, &
+	 call StoreError(USR_ERRNO, subname, &
 	      & cause_c='grid '//trim(subname)//' not found')
       endif
       
@@ -759,7 +759,7 @@ contains
 	& spcoordvars, ancilcrdvars, &
 	& title, source, institution, conventions, gt_version, proc, &
         & domain_div, subdomfst )
-      use dc_error, only: USR_EINT, StoreError
+      use dc_error, only: USR_ERRNO, StoreError
       implicit none
       character(len=*), intent(in)     :: name
       character(len=*), intent(in)     :: longname
@@ -807,7 +807,7 @@ contains
          
       if ( present_and_true(domain_div) ) then
          hist%domain_div = .true.
-         if (.not. present(subdomfst)) call StoreError(USR_EINT, subname, &
+         if (.not. present(subdomfst)) call StoreError(USR_ERRNO, subname, &
               & cause_c='When domain_div is present and true, subdomfst '// &
               & 'must also be present.')
       else
@@ -817,7 +817,7 @@ contains
       if (hist%domain_div .and. &
            & (minval(slfst(1:sprank)).le.0 .or. &
            &  minval(sllst(1:sprank)).lt.0) ) then
-	 call StoreError(USR_EINT, subname, &
+	 call StoreError(USR_ERRNO, subname, &
               & cause_c='When the domain is divided, output-domain '//&
               & 'limiting from the end by using negative indices is not '//&
               & 'available, since the whole domain size is not known. '//&
@@ -866,16 +866,16 @@ contains
          hist%dimsizes(i) = (hist%sllst(i)-hist%slfst(i))/hist%slstp(i) + 1
          if (.not.hist%domain_div) then
             if (hist%slfst(i)<=0 .or. hist%slfst(i)>aryshape(i)) &
-                 & call StoreError(USR_EINT, subname, cause_c= &
+                 & call StoreError(USR_ERRNO, subname, cause_c= &
                  &   'str not within the index range for dim:',cause_i=i)
             if (hist%sllst(i)<=0 .or. hist%sllst(i)>aryshape(i)) &
-                 & call StoreError(USR_EINT, subname, cause_c= &
+                 & call StoreError(USR_ERRNO, subname, cause_c= &
                  &   'end not within the index range for dim:',cause_i=i)
             if (hist%slstp(i)<=0) &
-                 & call StoreError(USR_EINT, subname, &
+                 & call StoreError(USR_ERRNO, subname, &
                  &   cause_c='step not positive for dim:', cause_i=i)
             if (hist%dimsizes(i)<=0) &
-                 & call StoreError(USR_EINT, subname, &
+                 & call StoreError(USR_ERRNO, subname, &
                  &   cause_c='negative dimsize for dim:', cause_i=i)
          endif
          hist%size = hist%size * hist%dimsizes(i)
