@@ -2,7 +2,7 @@ program dc_hash_test
   use dc_types, only: STRING
   use dc_test, only: Compare
   use dc_string, only: StoA
-  use dc_hash, only: HASH, Put, Put_Line, Get, Size, Delete
+  use dc_hash, only: HASH, Put, Put_Line, Get, Number, Delete
   use dc_trace, only: SetDebug
   implicit none
   type(HASH) :: hashv
@@ -27,19 +27,19 @@ continue
   call Compare('Put, Get test 4', 'demo', value)
   call Compare('Put, Get test 5', .true., found)
 
-  call Compare('Size test', 3, size(hashv))
+  call Compare('Number test', 3, number(hashv))
 
   call Delete(hashv, 'hogehoge')
-  call Compare('Delete test 1', 3, size(hashv))
+  call Compare('Delete test 1', 3, number(hashv))
   
   call Delete(hashv, 'hoge')
-  call Compare('Delete test 2', 2, size(hashv))
+  call Compare('Delete test 2', 2, number(hashv))
   
   call Delete(hashv, 'key')
-  call Compare('Delete test 3', 1, size(hashv))
+  call Compare('Delete test 3', 1, number(hashv))
   
   call Delete(hashv, 'local')
-  call Compare('Delete test 4', 0, size(hashv))
+  call Compare('Delete test 4', 0, number(hashv))
   
   call Put(hashv, 'new', 'val1')
 !  call Put_Line(hashv)
