@@ -14,7 +14,8 @@ MKDIR=${MKDIR:-mkdir}
 
 ##### some definitions #####
 
-date_to_unknown='s/[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]T[0-9][0-9]:[0-9][0-9]:[0-9][0-9][+-][0-9][0-9]:[0-9][0-9]/unknown/'
+history_to_unknown='s/:history = ".*>/:history = "unknown unknown>/'
+#date_to_unknown='s/[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]T[0-9][0-9]:[0-9][0-9]:[0-9][0-9][+-][0-9][0-9]:[0-9][0-9]/unknown/'
 delete_orig='s/\.orig//' 
 
 files="tmp.nc tmp1.nc tmp2_t0.nc tmp2_t120.nc tmp2_t240.nc tmp3.nc"
@@ -26,7 +27,7 @@ test -d xhistauto || $MKDIR xhistauto
 cd xhistauto
 for file in $origfiles
 do
-   ncdump $file | sed -e $date_to_unknown -e $delete_orig > $file.cdl
+   ncdump $file | sed -e "$history_to_unknown" -e $delete_orig > $file.cdl
 done
 cd ..
 
@@ -42,7 +43,7 @@ done
 cd xhistauto
 for file in $files
 do
-    ncdump $file | sed $date_to_unknown > $file.cdl
+    ncdump $file | sed "$history_to_unknown" > $file.cdl
 done
 
 ##### test ######
